# Graphix IBMQ interface

![PyPI](https://img.shields.io/pypi/v/graphix-ibmq)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/graphix-ibmq)

Provides an interface to run MBQC pattern (`graphix.Pattern`) on IBM quantum devices as well as the Aer simulators.

Requires [graphix](https://github.com/TeamGraphix/graphix) to generate the measurement pattern.

## Installation
install with `pip`
```
 $ pip install graphix-ibmq
```
<!-- This can be installed as part of graphix, by
```
 $ pip install graphix[extra]
``` -->

## License

[Apache License 2.0](LICENSE)

## Note

this project is not associated with IBM or IBMQuantum.



